visualize_vars: Visualize a df with two specified variables and an optional...

View source: R/visualize_vars.R

visualize_varsR Documentation

Visualize a df with two specified variables and an optional alpha value

Description

Visualize a df with two specified variables and an optional alpha value

Usage

visualize_vars(df, x, y, alpha = 0.4)

Arguments

df

A data frame or extension of it

x

A numeric variable shown on x-axis

y

A numeric variable shown on y-axis

alpha

number is default to 0.4. If the viewers want to change anything here, you can set alpha as a decimal number in the function.

Value

ggplot point graph of two variables from same df

Examples

visualize_vars(mtcars, mpg, cyl)
visualize_vars(data.frame(x = 1, y =2), x,y)

DSCI-310/DSCI-310-Group-8-package documentation built on April 21, 2022, 3:55 a.m.