View source: R/visualize_vars.R
| visualize_vars | R Documentation |
Visualize a df with two specified variables and an optional alpha value
visualize_vars(df, x, y, alpha = 0.4)
df |
A data frame or extension of it |
x |
A numeric variable shown on x-axis |
y |
A numeric variable shown on y-axis |
alpha |
number is default to 0.4. If the viewers want to change anything here, you can set alpha as a decimal number in the function. |
ggplot point graph of two variables from same df
visualize_vars(mtcars, mpg, cyl) visualize_vars(data.frame(x = 1, y =2), x,y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.